| nnsolve-package | R Documentation |
This package provides a fast algorithm for solving non-negative least squares problems. It implements the Fast Non-Negative Least Squares algorithm of Bro and De Jong (1997).
Maintainer: Nikolaos Kontemeniotis kontemeniotisn@gmail.com
Authors:
Michail Tsagris mtsagris@uoc.gr
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.